@@ -1,7 +1,9 @@
 import os
-from doreah.settings import config as settingsconfig
 from doreah.configuration import Configuration
 from doreah.configuration import types as tp
+from doreah.keystore import KeyStore
+
+from .__pkginfo__ import VERSION
 
 
 
@@ -70,9 +72,8 @@ directory_info = {
 }
 
 # function that
-# 1) checks if folder has been specified by user
-# 2) if not, checks if one has been in use before and writes it to dict/config
-# 3) if not, determines which to use and writes it to dict/config
+#   checks if one has been in use before and writes it to dict/config
+#   if not, determines which to use and writes it to dict/config
 # returns determined folder
 def find_good_folder(datatype,configobject):
 	info = directory_info[datatype]
@@ -110,9 +111,13 @@ else:
 	found_new_config_dir = False
 	# remember whether we had to find our config dir or it was user-specified
 
+os.makedirs(maloja_dir_config,exist_ok=True)
+
 oldsettingsfile = pthj(maloja_dir_config,"settings","settings.ini")
 newsettingsfile = pthj(maloja_dir_config,"settings.ini")
 
+
+
 if os.path.exists(oldsettingsfile):
 	os.rename(oldsettingsfile,newsettingsfile)
 
@@ -160,9 +165,11 @@ malojaconfig = Configuration(
 			"scrobble_lastfm":(tp.Boolean(),									"Proxy-Scrobble to Last.fm",	False),
 			"lastfm_api_key":(tp.String(),										"Last.fm API Key",				None),
 			"lastfm_api_secret":(tp.String(),									"Last.fm API Secret",			None),
+			"lastfm_api_sk":(tp.String(),										"Last.fm API Session Key",		None),
+			"lastfm_username":(tp.String(),										"Last.fm Username",				None),
+			"lastfm_password":(tp.String(),										"Last.fm Password",				None),
 			"spotify_api_id":(tp.String(),										"Spotify API ID",				None),
 			"spotify_api_secret":(tp.String(),									"Spotify API Secret",			None),
-			"lastfm_api_key":(tp.String(),										"Last.fm API Key",				None),
 			"audiodb_api_key":(tp.String(),										"TheAudioDB API Key",			None),
 			"track_search_provider":(tp.String(),								"Track Search Provider",		None),
 			"send_stats":(tp.Boolean(),											"Send Statistics",				None),
@@ -225,6 +232,8 @@ for datatype in ("state","cache","logs"):
 
 
 
+
+
 ### STEP 4 - this is where all the guessing about previous installation ends
 ###          we have our definite settings and are now just generating the real
 ###          folder names for everything
@@ -252,7 +261,7 @@ data_directories = {
 	"images":pthj(dir_settings['state'],"images"),
 	"scrobbles":pthj(dir_settings['state'],"scrobbles"),
 	"rules":pthj(dir_settings['config'],"rules"),
-	"clients":pthj(dir_settings['config'],"clients"),
+	"clients":pthj(dir_settings['config']),
 	"settings":pthj(dir_settings['config']),
 	"css":pthj(dir_settings['config'],"custom_css"),
 	"logs":pthj(dir_settings['logs']),
@@ -266,6 +275,13 @@ data_dir = {
 
 
 
+### write down the last ran version
+with open(pthj(dir_settings['state'],".lastmalojaversion"),"w") as filed:
+	filed.write(VERSION)
+	filed.write("\n")
+
+
+
 
 
 ### DOREAH CONFIGURATION
@@ -291,7 +307,27 @@ config(
 	}
 )
 
-settingsconfig._readpreconfig()
+
+
+
+### API KEYS
+
+
+
+### symmetric keys are fine for now since we hopefully use HTTPS
+apikeystore = KeyStore(file=data_dir['clients']("apikeys.yml"),save_endpoint="/apis/mlj_1/apikeys")
+
+oldfile = pthj(dir_settings['config'],"clients","authenticated_machines.tsv")
+if os.path.exists(oldfile):
+	try:
+		from doreah import tsv
+		clients = tsv.parse(oldfile,"string","string")
+		for key,identifier in clients:
+			apikeystore[identifier] = key
+		os.remove(oldfile)
+	except:
+		pass
+
 
 # what the fuck did i just write
 # this spaghetti file is proudly sponsored by the rice crackers i'm eating at the
